@@ -1,29 +1,29 @@
 validity.PTPattern <- function(object)
 {
   # Data should consist of a raw maximumPatternTableRowCount x maximumTrackCount*4 matrix
-  if (!all(dim(object@data) == c(maximumPatternTableRowCount, maximumTrackCount*4))) return (F)
+  if (!all(dim(object@data) == c(maximumPatternTableRowCount, maximumTrackCount*4))) return (FALSE)
   # data should be of type raw
-  if (typeof(object@data) != "raw") return (F)
+  if (typeof(object@data) != "raw") return (FALSE)
   # tracks should also be OK
   trackdat <- do.call(rbind, lapply(as.list(1:maximumTrackCount), function (x) {
     object@data[,-3 + ((x*4):(x*4 + 3))]
   }))
   # max. 32 samples (including number 0) allowed:
   samp.num <- hiNybble(trackdat[,1])*0x01 + hiNybble(trackdat[,3])
-  if (any(samp.num > 0x1F)) return (F)
+  if (any(samp.num > 0x1F)) return (FALSE)
 
   per      <- loNybble(trackdat[,1])*0x100 + as.integer(trackdat[,2])
   oct      <- octave(per)
 
   # only octaves 1 up to 3 are allowed:
-  if (any(!(oct[per != 0] %in% c(1:3)))) return (F)
+  if (any(!(oct[per != 0] %in% c(1:3)))) return (FALSE)
 
   # only period values from period_table are allowed:
   if (any(!(per[per != 0] %in% unlist(ProTrackR::period_table[ProTrackR::period_table$tuning == 0,
                                                     !(names(ProTrackR::period_table) %in% c("octave", "tuning"))]))))
-      return (F)
+      return (FALSE)
 
-  return(T)
+  return(TRUE)
 }
 
 #' The PTPattern class
@@ -72,7 +72,7 @@ setClass("PTPattern",
          representation(data = "matrix"),
          prototype(data = matrix(raw(maximumPatternTableRowCount*maximumTrackCount*4),
                                  ncol = maximumTrackCount*4,
-                                 nrow = maximumPatternTableRowCount, byrow = T)),
+                                 nrow = maximumPatternTableRowCount, byrow = TRUE)),
          validity = validity.PTPattern)
 
 #' @rdname as.character
